@@ -15,13 +15,20 @@ export { detect, getImageArchive, extractImageDetails, pullIfNotLocal };
 
 const debug = Debug("snyk");
 
+async function getInspectResult(
+  docker: Docker,
+  targetImage: string,
+): Promise<DockerInspectOutput> {
+  const info = await docker.inspectImage(targetImage);
+  return JSON.parse(info.stdout)[0];
+}
+
 async function detect(
   targetImage: string,
   options?: DockerOptions,
 ): Promise<DockerInspectOutput> {
   const docker = new Docker(targetImage, options);
-  const info = await docker.inspectImage(targetImage);
-  return JSON.parse(info.stdout)[0];
+  return getInspectResult(docker, targetImage);
 }
 
 function cleanupCallback(imagePath: string, imageName: string) {
@@ -34,6 +41,90 @@ function cleanupCallback(imagePath: string, imageName: string) {
   };
 }
 
+async function pullWithDockerBinary(
+  docker: Docker,
+  targetImage: string,
+  saveLocation: string,
+  username: string | undefined,
+  password: string | undefined,
+  platform: string | undefined,
+): Promise<boolean> {
+  let pullAndSaveSuccessful = false;
+  try {
+    if (username || password) {
+      debug(
+        "using local docker binary credentials. the credentials you provided will be ignored",
+      );
+    }
+    await docker.pullCli(targetImage, { platform });
+    await docker.save(targetImage, saveLocation);
+    return (pullAndSaveSuccessful = true);
+  } catch (err) {
+    debug(`couldn't pull ${targetImage} using docker binary: ${err}`);
+
+    if (
+      err.stderr &&
+      err.stderr.includes("unknown operating system or architecture")
+    ) {
+      throw new Error("Unknown operating system or architecture");
+    }
+    return pullAndSaveSuccessful;
+  }
+}
+
+async function pullFromContainerRegistry(
+  docker: Docker,
+  targetImage: string,
+  imageSavePath: string,
+  username: string | undefined,
+  password: string | undefined,
+): Promise<void> {
+  const { hostname, imageName, tag } = await extractImageDetails(targetImage);
+  debug(
+    `Attempting to pull: registry: ${hostname}, image: ${imageName}, tag: ${tag}`,
+  );
+  await docker.pull(
+    hostname,
+    imageName,
+    tag,
+    imageSavePath,
+    username,
+    password,
+  );
+}
+
+async function pullImage(
+  docker: Docker,
+  targetImage: string,
+  saveLocation: string,
+  imageSavePath: string,
+  username: string | undefined,
+  password: string | undefined,
+  platform: string | undefined,
+): Promise<void> {
+  if (await Docker.binaryExists()) {
+    const pullAndSaveSuccessful = await pullWithDockerBinary(
+      docker,
+      targetImage,
+      saveLocation,
+      username,
+      password,
+      platform,
+    );
+    if (pullAndSaveSuccessful) {
+      return;
+    }
+  }
+
+  await pullFromContainerRegistry(
+    docker,
+    targetImage,
+    imageSavePath,
+    username,
+    password,
+  );
+}
+
 /**
  * In the case that an `ImageType.Identifier` is detected we need to produce
  * an image archive, either by saving the image if it's already loaded into
@@ -53,12 +144,14 @@ function cleanupCallback(imagePath: string, imageName: string) {
  *    `latest`.
  * @param {string} [username] - Optional username for private repo auth.
  * @param {string} [password] - Optional password for private repo auth.
+ * @param {string} [platform] - Optional platform parameter to pull specific image arch.
  */
 async function getImageArchive(
   targetImage: string,
   imageSavePath: string,
   username?: string,
   password?: string,
+  platform?: string,
 ): Promise<ArchiveResult> {
   const docker = new Docker(targetImage);
   mkdirp.sync(imageSavePath);
@@ -67,51 +160,49 @@ async function getImageArchive(
     removeCallback: cleanupCallback(imageSavePath, "image.tar"),
   };
   const saveLocation: string = path.join(destination.name, "image.tar");
+  let inspectResult: DockerInspectOutput | undefined;
 
   try {
-    await docker.save(targetImage, saveLocation);
+    inspectResult = await getInspectResult(docker, targetImage);
+  } catch {
+    debug(`${targetImage} does not exist locally, proceeding to pull image.`);
+  }
+
+  if (inspectResult === undefined) {
+    await pullImage(
+      docker,
+      targetImage,
+      saveLocation,
+      imageSavePath,
+      username,
+      password,
+      platform,
+    );
 
     return {
       path: saveLocation,
       removeArchive: destination.removeCallback,
     };
-  } catch {
-    debug(
-      `${targetImage} does not exist locally, proceeding to pull image from remote registry.`,
+  }
+
+  if (
+    platform !== undefined &&
+    inspectResult &&
+    !isLocalImageSameArchitecture(platform, inspectResult.Architecture)
+  ) {
+    await pullImage(
+      docker,
+      targetImage,
+      saveLocation,
+      imageSavePath,
+      username,
+      password,
+      platform,
     );
+  } else {
+    await docker.save(targetImage, saveLocation);
   }
 
-  if (await Docker.binaryExists()) {
-    try {
-      if (username || password) {
-        debug(
-          "using local docker binary credentials. the credentials you provided will be ignored",
-        );
-      }
-
-      await docker.pullCli(targetImage);
-      await docker.save(targetImage, saveLocation);
-      return {
-        path: saveLocation,
-        removeArchive: destination.removeCallback,
-      };
-    } catch (err) {
-      debug(`couldn't pull ${targetImage} using docker binary: ${err}`);
-    }
-  }
-
-  const { hostname, imageName, tag } = await extractImageDetails(targetImage);
-  debug(
-    `Attempting to pull: registry: ${hostname}, image: ${imageName}, tag: ${tag}`,
-  );
-  await docker.pull(
-    hostname,
-    imageName,
-    tag,
-    imageSavePath,
-    username,
-    password,
-  );
   return {
     path: saveLocation,
     removeArchive: destination.removeCallback,
@@ -155,6 +246,22 @@ async function extractImageDetails(targetImage: string): Promise<ImageDetails> {
   };
 }
 
+function isLocalImageSameArchitecture(
+  platformOption: string,
+  inspectResultArchitecture: string,
+): boolean {
+  let platformArchitecture: string;
+  try {
+    // Note: this is using the same flag/input pattern as the new Docker buildx: eg. linux/arm64/v8
+    platformArchitecture = platformOption.split("/")[1];
+  } catch (error) {
+    debug(`Error parsing platform flag: '${error}'`);
+    return false;
+  }
+
+  return platformArchitecture === inspectResultArchitecture;
+}
+
 async function pullIfNotLocal(targetImage: string, options?: DockerOptions) {
   const docker = new Docker(targetImage);
   try {
