@@ -1,3 +1,4 @@
+import { normalize as normalizePath } from "path";
 import { IAptFiles } from "../../analyzer/types";
 import { getContentAsString } from "../../extractor";
 import { ExtractAction, ExtractedLayers } from "../../extractor/types";
@@ -5,13 +6,15 @@ import { streamToString } from "../../stream-utils";
 
 export const getDpkgFileContentAction: ExtractAction = {
   actionName: "dpkg",
-  filePathMatches: (filePath) => filePath === "/var/lib/dpkg/status",
+  filePathMatches: (filePath) =>
+    filePath === normalizePath("/var/lib/dpkg/status"),
   callback: streamToString,
 };
 
 export const getExtFileContentAction: ExtractAction = {
   actionName: "ext",
-  filePathMatches: (filePath) => filePath === "/var/lib/apt/extended_states",
+  filePathMatches: (filePath) =>
+    filePath === normalizePath("/var/lib/apt/extended_states"),
   callback: streamToString,
 };
 
